<?
/**************************************************************
Skull-Splitter's PHP Photos
Copyright (C) 2005  Soeren Boysen

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
**************************************************************/


/* Defining functions */


/**************************************************
* This function gets folder- and filenames of photos and
* puts it into a multidimensional array. Optionally a list of
* filenames to be excluded can be parsed to it. The argument
* discriptions below.
* 
* >> Arguments:
*   
*   $dir          --> root directory name to look in
*   $tempExclude  --> a string of filenames to be excluded in each
*                     event directory seperated by space (" ")
* 
* 
* >> Example output array: 
*
* Array (
*     [dirOne] => Array
*                   (
*                     [0] => fileOne.txt
*                     [1] => fileThree.txt
*                     [2] => fileTwo.txt
*                   )
*     [dirThree] => Array
*                   (
*                     [0] => fileOne.txt
*                     [1] => fileThree.txt
*                     [2] => fileTwo.txt
*                   )
*     [dirTwo] => Array
*                   (
*                     [0] => fileOne.txt
*                     [1] => fileThree.txt
*                     [2] => fileTwo.txt
*                   )
*        )
* 
**************************************************/

function prepPhotoArray($dir, $tempExclude = "")
  {
    $handle = opendir($dir);
    while(false !== ($file = readdir($handle)))
      {
        if($file != '.' && $file != '..')
          {
            $path = $dir.'/'.$file;
            
            if(empty($tempExclude))   // If there was no value for the second argument parsed
              {
                if(is_dir($path))
                  {
                    $output[$file] = prepPhotoArray($path);
                  }
                if(is_file($path))
                  {
                    $output[] = $file;
                  }
              }
            else
              {
                $exclude = explode(" ", $tempExclude);
                
                if(is_dir($path))
                  {
                    $output[$file] = prepPhotoArray($path, $tempExclude);
                  }
                if(is_file($path))
                  {
                    foreach($exclude as $value)
                      {
                        if($path != $dir.'/'.$value)
                          {
                            $output[] = $file;
                          }
                      }
                  }
              }
          }
      }
    return isset($output)?$output:false;
    closedir($handle);
  }


/**************************************************
* This function expects a 2D array of dir names in its first
* dimension and their containing filenames in the second
* dimension.
* It returns a 2D array with the dir name as the key in the first
* dimension. The value of which is another array with index [0]
* being the dir names except that the leading date is cut off
* (the first 9 characters) and all underscores (_) get replaced
* by spaces (" "). Index [1] contains the date formattes as
* this: DD.MM.YYYY
* 
* >> Arguments:
*   
*   $dirArray     --> expects a 2D array of dir names in its first
*                     dimension and their containing filenames in the
*                     second dimension.
*
* >> Example value for $dirArray
*
*                     Array (
*                         [20030512-Mixed_stuff] => Array
*                                       (
*                                         [0] => fileOne.txt
*                                         [1] => fileThree.txt
*                                         [2] => fileTwo.txt
*                                       )
*                         [20000911-Random_pictures] => Array
*                                       (
*                                         [0] => fileOne.txt
*                                         [1] => fileThree.txt
*                                         [2] => fileTwo.txt
*                                       )
*                         [19970209-Other_things_that_nobody_cares_about] => Array
*                                       (
*                                         [0] => fileOne.txt
*                                         [1] => fileThree.txt
*                                         [2] => fileTwo.txt
*                                       )
*                            )
* 
* >> Example output array: 
*
*                     Array (
*                         [20030512-Mixed_stuff] => Array (
*                                                       [name] => "Mixed stuff"
*                                                       [date] => "12.05.2003"
*                                                         )
*                         [20000911-Random_pictures] => Array (
*                                                       [name] => "Random pictures"
*                                                       [date] => "11.09.2000"
*                                                             )
*                         [19970209-Other_things_that_nobody_cares_about] => Array (
*                                                       [name] => "Other things that nobody cares about"
*                                                       [date] => "09.02.1997"
*                                                                                  )
*                            )
* 
**************************************************/

function stripDirNames($dirArray)
  {
    foreach($dirArray as $key => $value)
      {
        $year   = substr($key, 0, 4);
        $month  = substr($key, 4, 2);
        $day    = substr($key, 6, 2);
        $date   = $day.".".$month.".".$year;
        
        $tempOutput = substr($key, 9);                    // At index 9 the event name starts. Get rid of everything before that
        $tempOutput = str_replace("_", " ", $tempOutput); // Replace all underscores (_) by spaces
        
        $output[$key]['name'] = $tempOutput;    // Place the formatted event name in the $output array at index of the dir name, in the 'name' index of the second dimension
        $output[$key]['date'] = $date;          // Place the formatted date in the $output array at index of the dir name, in the 'date' index of the second dimension
      }
    return isset($output)?$output:false;
  }


?>